@@ -26,7 +26,8 @@ ai = on_alconna(
     Alconna(
         "AI",
         Args["user_input?", str],
-        Option("-重置|--reset"),
+        Option("-r|--reset"),
+        Option("-i|--image"),
     ),
     use_cmd_start=True,
     block=True,
@@ -39,6 +40,13 @@ async def ai_reset():
     shared_context = []
     await ai.finish("上下文已重置")
 
+@ai.assign("image")
+async def ai_image(user_input: Match[str]):
+    if user_input.available:
+        global REPLY_IMAGE
+        REPLY_IMAGE = True
+        ai.set_path_arg("user_input", user_input.result)
+
 @ai.handle()
 async def handle_function(user_input: Match[str]):
     if user_input.available:
@@ -46,6 +54,8 @@ async def handle_function(user_input: Match[str]):
 
 @ai.got_path("user_input", prompt="请输入有效问题")
 async def got_location(user_input: str):
+    if not user_input.strip():
+        await ai.reject("你真的输入了有效问题吗?请输入有效问题")
     global shared_context
     shared_context.append({"role": "user", "content": user_input})
     if len(shared_context) > MAX_CONTEXT_LENGTH:
@@ -82,4 +92,4 @@ __plugin_meta__ = PluginMetadata(
     type="application",
     homepage="https://github.com/lyqgzbl/nonebot-plugin-githubmodels",
     supported_adapters=None,
-)
\ No newline at end of file
+)
